==> haskell-binary-orphans-1.0.1-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-orphans
version:              1.0.1
visibility:           public
id:                   binary-orphans-1.0.1-EoeifjL4SNi4ZwSGCgB321
key:                  binary-orphans-1.0.1-EoeifjL4SNi4ZwSGCgB321
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  51ad4eb16b418c3a14734364470013e9
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.0.1/site-local/binary-orphans-1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/binary-orphans-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/binary-orphans-1.0.1
hs-libraries:         HSbinary-orphans-1.0.1-EoeifjL4SNi4ZwSGCgB321
depends:              base-4.15.0.0 binary-0.8.8.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-1.0.1-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 binary-orphans
version:              1.0.1
visibility:           public
id:                   binary-orphans-1.0.1-5romYc7swgcApocPz3GTyk
key:                  binary-orphans-1.0.1-5romYc7swgcApocPz3GTyk
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Compatibility package for binary; provides instances
description:
    This package provides instances defined in later versions of @binary@ package

    Prior version 1 this packages provided instances for other packages.
    That functionality is moved to [binary-instances](https://hackage.haskell.org/package/binary-instances) package.

category:             Data, Binary, Parsing, Compatibility
abi:                  d9a28679467ef7057fefbe88962c50d8
exposed:              True
exposed-modules:      Data.Binary.Orphans
import-dirs:          /usr/lib/ghc-9.0.1/site-local/binary-orphans-1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/binary-orphans-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/binary-orphans-1.0.1
hs-libraries:         HSbinary-orphans-1.0.1-5romYc7swgcApocPz3GTyk
depends:              base-4.15.0.0 binary-0.8.8.0 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock

haddock-html:         /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
